TPIE - The Templated Portable I/O Environment
=============================================

NIX: [![Build Status](https://travis-ci.org/thomasmoelhave/tpie.svg?branch=master)](https://travis-ci.org/thomasmoelhave/tpie)
Windows: [![Build status Windows](https://ci.appveyor.com/api/projects/status/570fltgf1ko5twna/branch/master?svg=true)](https://ci.appveyor.com/project/antialize/tpie/branch/master)

The TPIE (Templated Portable I/O Environment) library is a tool box providing
efficient and convenient tools to ease the implementation of algorithm and data
structures on very large sets of data.

For help, installation, usage and documentation, visit the
[TPIE homepage](http://www.madalgo.au.dk/tpie/).
[API documentation](http://www.madalgo.au.dk/tpie/doc/) is also hosted there.
